@@ -2,17 +2,41 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: expp1
+### code chunk number 1: library
+###################################################
+library(polyapost)
+
+
+###################################################
+### code chunk number 2: R
+###################################################
+foo <- getRversion()
+baz <- library(help = "polyapost")
+baz <- baz$info[[1]]
+baz <- baz[grep("Version", baz)]
+baz <- sub("^Version: *", "", baz)
+qux <- library(help = "rcdd")
+qux <- qux$info[[1]]
+qux <- qux[grep("Version", qux)]
+qux <- sub("^Version: *", "", qux)
+
+
+###################################################
+### code chunk number 3: seed
 ###################################################
 set.seed(313)
-library(polyapost)
+
+
+###################################################
+### code chunk number 4: expp1
+###################################################
 ysamp<-c(0,1)
 K<-10-2
 polyap(ysamp,K)
 
 
 ###################################################
-### code chunk number 2: expp2
+### code chunk number 5: expp2
 ###################################################
 y<-rgamma(500,5)
 mean(y)
@@ -26,7 +50,7 @@ round(simmns,digits=2)
 
 
 ###################################################
-### code chunk number 3: expp3
+### code chunk number 6: expp3
 ###################################################
 x<-sort(rgamma(500,10))
 y<-rnorm(500,20 + 2*x,3)
@@ -37,7 +61,7 @@ mnx
 
 
 ###################################################
-### code chunk number 4: exp3.2
+### code chunk number 7: exp3.2
 ###################################################
 samp<-sort(c(sample(1:250,8),sample(251:500,17)))
 ysamp<-y[samp]
@@ -53,7 +77,7 @@ b3<-9.7
 
 
 ###################################################
-### code chunk number 5: exp3.4
+### code chunk number 8: exp3.4
 ###################################################
 eps<-0.001
 initsol<-feasible(A1,A2,A3,b1,b2,b3,eps)
@@ -61,7 +85,7 @@ initsol[c(3,9,25)]
 
 
 ###################################################
-### code chunk number 6: exp3.6
+### code chunk number 9: exp3.6
 ###################################################
 burnin<-1
 reps<-200001
@@ -70,21 +94,21 @@ mean(out[[1]])
 
 
 ###################################################
-### code chunk number 7: figstrat
+### code chunk number 10: figstrat
 ###################################################
 plot(out[[1]][seq(1,200001,by=200)])
 #plot(out[[1]])
 
 
 ###################################################
-### code chunk number 8: exp3.7
+### code chunk number 11: exp3.7
 ###################################################
 out[[2]] 
 out[[3]] 
 
 
 ###################################################
-### code chunk number 9: exp3.8
+### code chunk number 12: exp3.8
 ###################################################
 A1<-rbind(rep(1,25))
 A2<--diag(25)
@@ -100,14 +124,14 @@ sqrt(var(out[[1]][subseq]))
 
 
 ###################################################
-### code chunk number 10: figcprs
+### code chunk number 13: figcprs
 ###################################################
 plot(out[[1]][subseq])
 #plot(out[[1]])
 
 
 ###################################################
-### code chunk number 11: exp3.9
+### code chunk number 14: exp3.9
 ###################################################
 K<-500-25
 simmns<-rep(0,1000)
@@ -119,13 +143,13 @@ sqrt(var(simmns))
 
 
 ###################################################
-### code chunk number 12: figprs
+### code chunk number 15: figprs
 ###################################################
 plot(simmns)
 
 
 ###################################################
-### code chunk number 13: exp4
+### code chunk number 16: exp4
 ###################################################
 A1<-rbind(rep(1,6),1:6)
 A2<-rbind(c(2,5,7,1,10,8),diag(-1,6))
@@ -139,10 +163,36 @@ round(out,digits=5)
 
 
 ###################################################
-### code chunk number 14: exp5
+### code chunk number 17: exp5
 ###################################################
 ysamp<-c(1,2,3)
 wts<-c(1,2,3)
 wtpolyap(ysamp,wts,25)
 
 
+###################################################
+### code chunk number 18: pp1.Rnw:527-528
+###################################################
+smp<-c(20,10,10,25,15,20)
+
+
+###################################################
+### code chunk number 19: exphr
+###################################################
+ mxcst<-rbind(c(1,0,0,1,0,0),c(0,1,0,0,1,0),c(1,1,1,0,0,0))
+ mncst<-c(5000/10000,3000/10000,6000/10000)
+ out<-hitrun(smp, a2=mxcst, b2=mncst, nbatch=20, blen=1000)
+
+
+###################################################
+### code chunk number 20: exphr-means
+###################################################
+ round(colMeans(out$batch), digits=3)
+
+
+###################################################
+### code chunk number 21: exphr-mcse
+###################################################
+ round(apply(out$batch, 2, sd) / sqrt(out$nbatch), digits=3)
+
+
